@@ -1,4 +1,4 @@
-package App::MonM; # $Id: MonM.pm 42 2014-12-17 12:33:09Z abalama $
+package App::MonM; # $Id: MonM.pm 51 2015-06-30 11:51:44Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::MonM - Simple Monitoring Tools
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 SYNOPSIS
 
@@ -106,6 +106,13 @@ The method returns status of "http" request. See L<monm> and README for details
 
 The method returns status of "checkit" request. See L<monm> and README for details
 
+=item B<checkitreport>
+
+    my $status = $monm->checkitreport;
+    print $monm->message if $status;
+
+The method returns status of "checkitreport" request. See L<monm> and README for details
+
 =item B<alertgrid_init, alertgrid_clear, alertgrid_config, alertgrid_server, alertgrid_client, alertgrid_snapshot, alertgrid_export>
 
     my $status = $monm->alertgrid_server( '' );
@@ -169,7 +176,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/ $VERSION /;
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 use CTKx;
 use CTK::Util;
@@ -222,6 +229,8 @@ use constant {
     SKIPPED     => "SKIPPED",   # for tests
     PASSED      => "PASSED",    # for tests
     FAILED      => "FAILED",    # for tests
+    UNKNOWN     => "UNKNOWN",   # for tests
+    PROBLEM     => "PROBLEM",   # for tests
 };
 
 our $SCREEN_INI;
@@ -943,6 +952,127 @@ sub checkit {
     
     $self->status;
 }
+sub checkitreport {
+    my $self = shift;
+    my %data = @_;
+    my $c = $self->ctkx->c;
+    my $config = $c->config;
+    my $name = $data{args} && $data{args}[0] ? $data{args}[0] : ''; #  
+    my $ymlfile = catfile($c->datadir,sprintf($data{ymlfile}, "")); #   
+    
+    my %ret; #  
+    
+    #  
+    start "Loading configuration data";
+    my $counts_node = node($config => 'checkit');
+    my @clist = ();
+    if ($counts_node && ref($counts_node) eq 'HASH') {
+        @clist = grep {is_hash($counts_node, $_) && value($counts_node, $_, 'enable')} keys(%$counts_node);
+    }
+    if (@clist) {
+        finish DONE;
+    } else {
+        finish ERROR;
+        $self->error("No counts found! Will be used all found counts");
+        debug $self->lasterror;
+        $c->log_info($self->lasterror);
+    }
+    debug Dumper($ymlfile);
+    
+    #   YAML
+    start "Loading statistical data from file $ymlfile";
+    my $yaml = {error => ''}; try { $yaml = YAML::Tiny::LoadFile($ymlfile) if -e $ymlfile } catch {$yaml->{error} = $_} ;
+    finish $yaml->{error} ? ERROR : DONE;
+    if ($yaml->{error}) {
+        $self->error($yaml->{error});
+        debug $self->lasterror;
+        $c->log_error($self->lasterror);
+    }
+    #debug "Input YAML:\n",Dumper($yaml);
+    $ret{yamlfile} = $ymlfile;
+    
+    #  
+    my $tbl = Text::SimpleTable->new(
+        [61, 'COUNT'],
+        [7,  'MESSAGE'],
+        [8,  'STATUS'], # OK, ERROR
+    );
+    my @tabled;
+    my $summary = 1;
+    if ($yaml->{error}) {
+        $summary = 0;
+    } else {
+        foreach my $nc (sort {$a cmp $b} @clist) {
+            start "Checking \"$nc\"";
+            my $data = array($yaml->{$nc});
+            my $message = join("",@$data);
+            my $status;
+            
+            if ($message eq '111') {
+                $status = OK;
+            } elsif ($message eq '000') {
+                $status = PROBLEM;
+            } elsif ($message =~ '00') {
+                $status = PROBLEM;
+            } elsif ($message =~ '0') {
+                $status = UNKNOWN;
+            } else {
+                $status = FAILED;
+            }
+            $summary = 0 if $status ne "OK";
+            push @tabled, [$nc,$status,$message];
+            
+            $tbl->row($nc,$message,$status);
+
+            #  
+            finish $status;
+            $c->log_debug(sprintf("%-7s %s [%s]",$status, $nc, $message));
+        }
+    }
+    $tbl->hr if @tabled;
+    $ret{summary} = $summary ? OK : PROBLEM;
+    $tbl->row("SUMMARY",'',$ret{summary});
+    my $result = sprintf("COUNTS:\n%s", $tbl->draw);
+    #debug $result;
+
+    #          
+    my $maildata = node($config => 'sendmail');
+    if (value($maildata, "to")) {
+        my %ma = ();
+        foreach my $k (keys %$maildata) {
+            $ma{"-".$k} = value($maildata, $k);
+        }
+        $c->log_info("Sending report to e-mail");
+        
+
+        
+        $ma{'-subject'} ||= $summary
+            ? sprintf("MonM/%s CHECKUP Report", $VERSION)
+            : sprintf("MonM/%s CHECKUP ERROR Report", $VERSION);
+        $ma{'-message'} ||= $summary
+            ? sprintf("     \n\n%s", $result)
+            : sprintf("   \n\n%s", $result);
+        $ma{'-message'} .= "\n---\n"
+            . sprintf("Generated by    : MonM/%s\n", $VERSION)
+            . sprintf("Date generation : %s\n", localtime2date_time())
+            . sprintf("MonM Id         : %s\n", '$Id: MonM.pm 51 2015-06-30 11:51:44Z abalama $')
+            . sprintf("Time Stamp      : %s\n", $c->tms())
+            . sprintf("Configuration   : %s\n", $c->cfgfile)
+            . sprintf("Statistic file  : %s\n", $ymlfile)
+              ;
+        #$ma{'-attach'} = _attach($ma{'-attach'}) || [];
+        my $sent = send_mail(%ma);
+        $c->log_info(sprintf(" - %s:", $ma{'-to'}), $sent ? 'OK (Mail has been sent)' : 'FAILED (Mail was not sent)');
+    } else {
+        $c->log_error("Sending report disabled by user. Variable \"TO\" not defined");
+    }    
+
+    #  & 
+    my $rslt = $self->foutput("checkitreport", \%ret, \@tabled, [qw(COUNT STATUS MESSAGE)]);
+    _show_result_data(\$rslt, $self->opt("utf8")) if $self->opt('verbose');
+    
+    $self->status;
+}
 sub alertgrid_init {
     my $self = shift;
     my %data = @_;
